@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package App::Addex::AddressBook::AppleScript;
 {
-  $App::Addex::AddressBook::AppleScript::VERSION = '0.003';
+  $App::Addex::AddressBook::AppleScript::VERSION = '0.004';
 }
 use base qw(App::Addex::AddressBook);
 # ABSTRACT: Mac::Glue-less Addex adapter for Apple Address Book and Addex
@@ -163,6 +163,27 @@ sub _entrify {
     });
   }
 
+  CHECK_DEFAULT: {
+    if (@emails > 1 and my $default = $fields{default_email}) {
+      my $check;
+      if ($default =~ m{\A/(.+)/\z}) {
+        $default = qr/$1/;
+        $check   = sub { $_[0]->address =~ $default };
+      } else {
+        $check   = sub { $_[0]->label eq $default };
+      }
+
+      for my $i (0 .. $#emails) {
+        if ($check->($emails[$i])) {
+          unshift @emails, splice @emails, $i, 1 if $i != 0;
+          last CHECK_DEFAULT;
+        }
+      }
+
+      warn "no email found for $name matching $fields{default_email}\n";
+    }
+  }
+
   my $arg = {
     name   => $name,
     nick   => $person->{nickname},
@@ -176,6 +197,7 @@ sub _entrify {
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -184,7 +206,7 @@ App::Addex::AddressBook::AppleScript - Mac::Glue-less Addex adapter for Apple Ad
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
@@ -213,4 +235,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
